deploy

Function deploy 

pub fn deploy(
    signer: Pubkey,
    authority: Pubkey,
    amount: u64,
    round_id: u64,
    squares: [bool; 25],
    referrer: Option<Pubkey>,
    pooled: bool,
) -> Instruction
Deploy SOL to prospect on squares.

This function uses native SOL transfers and is used for:

  • Regular wallets (signer == authority)
  • Automations (bot-executed deploys, signer != authority, using native SOL from automation account balance)

Pass a referrer pubkey for new miners to set up referral. Set pooled to true to join the mining pool (rewards shared proportionally).