Module state

Module state 

Structs

Auction
Singleton auction configuration account
Automation
Board
Config
Micro
Micro account stores per-epoch totals for a specific well and epoch
Miner
OilPriceOracle
OIL price oracle (Valiant-backed; updated by centralized authority). Price is stored as FOGO lamports per 1 OIL: fee_lamports = claimable_atomic * price * 35 / (100 * ONE_OIL).
Plot
Plot account (one per wallet/authority)
Pool
Pool account holds all staking-related data and SOL rewards for stakers.
Referral
Referral account tracks a referrer’s stats and pending rewards.
Refinery
Refinery global state (singleton account)
Rig
Rig account (one per NFT mint, links NFT to on-chain stats)
RigConfig
Rig configuration (stats for each rig type)
Round
Share
Share account tracks a user’s contribution to a specific epoch for a specific well
Stake
Treasury
Treasury is a singleton account which is the mint authority for the OIL token and the authority of
Well
Well account (one per well)
Whitelist
Whitelist tracks access codes for pre-mine phase.

Enums

AutomationStrategy
OilAccount

Functions

auction_pda
automation_pda
board_pda
config_pda
micro_pda
miner_pda
oil_oracle_pda
plot_pda
pool_pda
pool_tokens_address
referral_pda
refinery_pda
rig_pda
round_pda
share_pda
stake_pda
stake_pda_with_id
treasury_pda
treasury_tokens_address
well_pda
whitelist_pda